#!/bin/sh

#dd if=app.scr of=/dev/mtdblock5 bs=16k seek=15
#dd if=bl.img of=/dev/mtdblock5 bs=16k seek=1
target_device="/dev/mtdblock5"
bootloader_file="u-boot.bin"
bootscript_file="u-boot.scr"

if [ ! -e "$bootloader_file" ]; then
  printf "Bootloader file does not exist!\\n"
  exit 1
fi

bootloader_filesize=$(ls -l $bootloader_file | awk '{ print $5 }')
bootscript_filesize=$(ls -l $bootscript_file | awk '{ print $5 }')

rm -rf /opt/userdata/uboot.temp
dd if=/dev/mtdblock5 bs=16k skip=1 count=14 of=/opt/userdata/uboot.temp 2>/dev/null;
installed_bootloader_checksum=$(dd if=/opt/userdata/uboot.temp  bs=${bootloader_filesize} count=1 2>/dev/null | md5sum | cut -d " " -f1)
rm -rf /opt/userdata/uboot.temp
dd if=/dev/mtdblock5 bs=16k skip=15 count=1 of=/opt/userdata/uboot.temp 2>/dev/null;
installed_bootscript_checksum=$(dd if=/opt/userdata/uboot.temp  bs=${bootscript_filesize} count=1 2>/dev/null | md5sum | cut -d " " -f1)
rm -rf /opt/userdata/uboot.temp

bootloader_checksum=$(md5sum "$bootloader_file" | cut -d " " -f1)
bootscript_checksum=$(md5sum "$bootscript_file" | cut -d " " -f1)

printf "bootloader filesize: ${bootloader_filesize} \\n"
printf "bootscript filesize: ${bootscript_filesize} \\n"

printf "Installed bootloader checksum: ${installed_bootloader_checksum} \\n"
printf "Devicepackage's bootloader checksum: ${bootloader_checksum} \\n"

printf "Installed bootscript checksum: ${installed_bootscript_checksum} \\n"
printf "Devicepackage's bootscript checksum: ${bootscript_checksum} \\n"

if [ "${installed_bootscript_checksum}" != "${bootscript_checksum}" ]; then
 printf "Exchange bootscript. Content is different.\n"
 dd if=${bootscript_file} of=/dev/mtdblock5 bs=16k seek=15 2>/dev/null
 success=$?
 printf "Exchange bootscript done. success: ${success}.\n"

 
else
 printf "Don't exchange bootscript. Content is equal.\n"
fi

if [ "${bootloader_checksum}" != "${installed_bootloader_checksum}" ]; then
 printf "Exchange bootloader. Content is different.\n"
 dd if=${bootloader_file} of=/dev/mtdblock5 bs=16k seek=1  2>/dev/null
 success=$?
 printf "Exchange bootloader done. success: ${success}.\n"
else
 printf "Don't exchange bootloader. Content is equal.\n"
fi

exit 0
